@@ -16,7 +16,7 @@ def svg2pdf(fin, fout=None, crop=True, text_to_path=False, export_area_page=True
     if text_to_path: # Good idea for inkscape which seems to bungle the fonts (space in font names?)
         cmd.append("-T")
     cmd.append(fin)
-    cmd.append(f"--export-filename={fout}")
+    cmd.append(f'--export-filename="{fout}"')
     # '-C', '--without-gui', f'--file={fin}', f'--export-pdf={fout}']
     # cmd = ['inkscape', '-C', '-T', '--without-gui', '--file=%s'%svg_fonts_layers[-1], '--export-pdf=%s' % pdf_nofonts_layers[-1]]
     execute_command(cmd)
